@@ -16,11 +16,9 @@
  * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
  * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGE.
- * 
+ * 输入法界面由示例代码修改而来，所以保留以上信息  --Eveing
  */
 
-#include "hildon-im-plugin.h"
-#include "hildon-im-ui.h"
 #include "py.c"
 
 #include <X11/Xatom.h>
@@ -28,11 +26,10 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-//#include <hildon/hildon.h>
+#include <hildon-im-plugin.h>
+#include <hildon-im-ui.h>
 
 #define G_DEBUG_DISABLE 1
-#define VERSION "0.0.3"
-
 #define BUTTON_WIDTH 80
 #define BUTTON_HIGHT 60
 #define HILDON_IM_FCITX_FKB_TYPE hildon_im_fcitx_fkb_get_type()
@@ -66,16 +63,16 @@ static const gchar** alpha_upper[] = {alpha_upper_0,
                                       alpha_upper_3, NULL};
 
 static const gchar* special_lower_0[] = {"1", "2", "3", "4", "5", "6", "7", "8", "9", "0", NULL};
-static const gchar* special_lower_1[] = {"@", "|", "#", "(", ")", "&", "*", "+", "=", NULL};
+static const gchar* special_lower_1[] = {"@", "|", "#", "\"", "\'", "&", "*", "+", "=", NULL};
 static const gchar* special_lower_2[] = {"/", "-", "_", "%", "\\", ":", ";", NULL};
-static const gchar* special_lower_3[] = {"\"", "\'", NULL};
+static const gchar* special_lower_3[] = {",", ".", NULL};
 static const gchar** special_lower[] = {special_lower_0,
                                         special_lower_1,
                                         special_lower_2,
                                         special_lower_3, NULL};
 static const gchar* special_upper_0[] = {"1", "2", "3", "4", "5", "6", "7", "8", "9", "0", NULL};
-static const gchar* special_upper_1[] = {"`", "<", ">", "{", "}", "[", "]", "$", "£", NULL};
-static const gchar* special_upper_2[] = {"%", "^", "½", "°", "¥", "~", "€", NULL};
+static const gchar* special_upper_1[] = {"`", "<", ">", "{", "}", "[", "]", "(", ")", NULL};
+static const gchar* special_upper_2[] = {"%", "^", "½", "°", "¥", "~", "$", NULL};
 static const gchar* special_upper_3[] = {"©", "®", NULL};
 static const gchar** special_upper[] = {special_upper_0,
                                         special_upper_1,
@@ -482,7 +479,7 @@ get_x11win_prop( Window win){
 //        g_debug( "check_x11win_classhint get undefined win" );
     }
     else
-//        g_debug( "check_x11win_classhint res_name = %s, res_class = %s", classhint.res_name, classhint.res_class );
+        g_debug( "check_x11win_classhint res_name = %s, res_class = %s", classhint.res_name, classhint.res_class );
     if ( g_strcmp0( classhint.res_class, "Browser" ) == 0 || g_strcmp0( classhint.res_class, "Osso-xterm" ) == 0){
 //        g_debug("check_x11win_classhint find browser or xterminal");
         return TRUE;
@@ -531,21 +528,18 @@ hildon_im_fcitx_fkb_enable (HildonIMPlugin *plugin,gboolean init)
   if (window_is_new)
   {
     priv->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_type_hint(GTK_WINDOW(priv->window), GDK_WINDOW_TYPE_HINT_DIALOG | GDK_WINDOW_TYPE_HINT_NOTIFICATION);
-    gtk_window_set_default_size(GTK_WINDOW(priv->window),800,480);
+    gtk_window_set_type_hint(GTK_WINDOW(priv->window), GDK_WINDOW_TYPE_HINT_DIALOG);
+    /*gtk_window_set_default_size(GTK_WINDOW(priv->window),800,480);*/
     gtk_window_set_decorated (GTK_WINDOW (priv->window), FALSE);
-    /*g_signal_connect(priv->window, "destroy", G_CALLBACK(close_win), self);*/
+    gtk_window_fullscreen(GTK_WINDOW (priv->window));
+    /*g_signal_connect(priv->window, "destroy", G_CALLBACK(close_fkb), self);*/
   }
-  /*
-      we don't really support this...
-    hildon_gtk_window_set_portrait_flags (GTK_WINDOW(priv->window),
-                                          HILDON_PORTRAIT_MODE_SUPPORT);
-   */
   hildon_im_ui_send_communication_message(priv->ui,
                                           HILDON_IM_CONTEXT_REQUEST_SURROUNDING_FULL);
   hildon_im_ui_play_sound(priv->ui, HILDON_IM_FINGER_TRIGGER_SOUND);
   priv->saved_offset = 0;
 
+  gtk_widget_show(GTK_WIDGET(priv->window));
   gdk_window_set_transient_for(GTK_WIDGET(priv->window)->window,
                                gtk_widget_get_root_window(GTK_WIDGET(priv->window)));
 
@@ -1017,9 +1011,9 @@ close_fkb (GtkWidget *button, gpointer user_data)
                                    gtk_text_buffer_get_selection_bound(buffer));
   gint offset = gtk_text_iter_get_offset(&start);
   gtk_text_buffer_get_bounds(buffer, &start, &end);
+  gchar *text = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+  GString *newstr = g_string_new(text);
   if(offset == gtk_text_iter_get_offset(&end)){
-    gchar *text = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
-    GString *newstr = g_string_new(text);
     gsize len = newstr->len;
     if(len > 0){
       if(newstr->str[len-1]=='\n'){
@@ -1027,15 +1021,15 @@ close_fkb (GtkWidget *button, gpointer user_data)
         newline = TRUE;
       }
     }
-    if (hildon_im_ui_get_commit_mode(priv->ui) == HILDON_IM_COMMIT_SURROUNDING)
-    {
-      hildon_im_ui_send_surrounding_content( priv->ui, newstr->str);
-    }else if(newline){
-      hildon_im_ui_send_communication_message (priv->ui,
-                                            HILDON_IM_CONTEXT_HANDLE_BACKSPACE);
-    }
-    g_string_free(newstr,FALSE);
   }
+  if (hildon_im_ui_get_commit_mode(priv->ui) == HILDON_IM_COMMIT_SURROUNDING)
+  {
+    hildon_im_ui_send_surrounding_content( priv->ui, newstr->str);
+  }else if(newline){
+    hildon_im_ui_send_communication_message (priv->ui,
+                                            HILDON_IM_CONTEXT_HANDLE_BACKSPACE);
+  }
+  g_string_free(newstr,FALSE);
   hildon_im_ui_restore_previous_mode(priv->ui);
   if(newline || priv->return_close){
     if (hildon_im_ui_get_commit_mode(priv->ui) == HILDON_IM_COMMIT_SURROUNDING)
@@ -1048,12 +1042,14 @@ close_fkb (GtkWidget *button, gpointer user_data)
 }
 static gboolean textview_copy (GtkButton *button, gpointer data)
 {
+  HildonIMFcitxFKBPrivate *priv;
   GtkClipboard *clipboard = NULL;
 
-  GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(data));
+  priv = HILDON_IM_FCITX_FKB_GET_PRIVATE(data);
+  GtkTextBuffer *buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(priv->text_view));
   clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
   gtk_text_buffer_copy_clipboard (GTK_TEXT_BUFFER(buffer), clipboard);
-//  hildon_banner_show_informationf(GTK_WIDGET(data),NULL,"复制");
+  gtk_button_set_label(GTK_BUTTON(priv->buttons[1][9]),"复制");
   return TRUE;
 }
 static gboolean textview_paste (GtkButton *button, gpointer data)
@@ -1138,8 +1134,8 @@ populate_window (HildonIMFcitxFKB *self)
   gtk_text_view_set_editable (GTK_TEXT_VIEW (priv->text_view), TRUE);
   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(priv->text_view), GTK_WRAP_WORD_CHAR);
   gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(priv->text_view), TRUE);
-  gtk_text_view_set_left_margin(GTK_TEXT_VIEW(priv->text_view), 8);
-  gtk_text_view_set_right_margin(GTK_TEXT_VIEW(priv->text_view), 8);
+  gtk_text_view_set_left_margin(GTK_TEXT_VIEW(priv->text_view), 10);
+  gtk_text_view_set_right_margin(GTK_TEXT_VIEW(priv->text_view), 10);
 
   gtk_widget_modify_font(GTK_WIDGET(priv->text_view),font);
   g_signal_connect(G_OBJECT(priv->text_view), "button-release-event",
@@ -1153,7 +1149,7 @@ populate_window (HildonIMFcitxFKB *self)
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), cut_menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), paste_menu);
   g_signal_connect(G_OBJECT(copy_menu), "activate",
-                         G_CALLBACK(textview_copy), priv->text_view);
+                         G_CALLBACK(textview_copy), self);
   g_signal_connect(G_OBJECT(cut_menu), "activate",
                          G_CALLBACK(textview_cut), self);
   g_signal_connect(G_OBJECT(paste_menu), "activate",
@@ -1176,7 +1172,6 @@ populate_window (HildonIMFcitxFKB *self)
   {
         priv->buttons[3][i] = gtk_button_new();
         gtk_button_set_focus_on_click(GTK_BUTTON(priv->buttons[3][i]),FALSE);
-        /*gtk_widget_set_size_request(priv->buttons[3][i], BUTTON_WIDTH, BUTTON_HIGHT);*/
         g_signal_connect(G_OBJECT(priv->buttons[3][i]), "pressed", G_CALLBACK(text_button_clicked), self);
         gtk_box_pack_start(GTK_BOX(priv->buttons[3][2]), GTK_WIDGET(priv->buttons[3][i]), TRUE, TRUE, 0);
   }
@@ -1213,6 +1208,7 @@ populate_window (HildonIMFcitxFKB *self)
       /* Chinese_switch button */
 
       priv->mode_button = gtk_button_new_with_label (chinese_mode?"拼":"英");
+      gtk_button_set_focus_on_click(GTK_BUTTON(priv->mode_button),FALSE);
       gtk_widget_set_size_request(priv->mode_button, BUTTON_WIDTH, BUTTON_HIGHT);
       gtk_box_pack_start(GTK_BOX(hbox), priv->mode_button, FALSE, FALSE, 0);
       g_signal_connect(priv->mode_button, "clicked", G_CALLBACK(switch_button_toggled), self);
